import { Directive, TemplateRef, ViewContainerRef, Input, Component, NgModule, isDevMode, Injectable, ɵɵdefineInjectable } from '@angular/core';
import { isOn, set } from 'feature-toggle-service';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleDirective {
    /**
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.isOn = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureToggle) {
            throw new Error('Attribute `featureToggle` should not be null or empty');
        }
        this.shouldRender();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.isOn !== isOn(this.featureToggle)) {
            this.shouldRender();
        }
    }
    /**
     * @private
     * @return {?}
     */
    shouldRender() {
        this.isOn = isOn(this.featureToggle);
        if (this.isOn) {
            this.viewContainer.createEmbeddedView(this.templateRef);
        }
        else {
            this.viewContainer.clear();
        }
    }
}
FeatureToggleDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[featureToggle]',
            },] }
];
/** @nocollapse */
FeatureToggleDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef }
];
FeatureToggleDirective.propDecorators = {
    featureToggle: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    FeatureToggleDirective.prototype.featureToggle;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleDirective.prototype.isOn;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleDirective.prototype.templateRef;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleDirective.prototype.viewContainer;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleWhenDisabledDirective {
    /**
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.isOn = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.featureToggleWhenDisabled) {
            throw new Error('Attribute `featureToggleWhenDisabled` should not be null or empty');
        }
        this.shouldRender();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.isOn !== isOn(this.featureToggleWhenDisabled)) {
            this.shouldRender();
        }
    }
    /**
     * @return {?}
     */
    shouldRender() {
        this.isOn = isOn(this.featureToggleWhenDisabled);
        if (!this.isOn) {
            this.viewContainer.createEmbeddedView(this.templateRef);
        }
        else {
            this.viewContainer.clear();
        }
    }
}
FeatureToggleWhenDisabledDirective.decorators = [
    { type: Directive, args: [{
                // tslint:disable-next-line: directive-selector
                selector: '[featureToggleWhenDisabled]',
            },] }
];
/** @nocollapse */
FeatureToggleWhenDisabledDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef }
];
FeatureToggleWhenDisabledDirective.propDecorators = {
    featureToggleWhenDisabled: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    FeatureToggleWhenDisabledDirective.prototype.featureToggleWhenDisabled;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleWhenDisabledDirective.prototype.isOn;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleWhenDisabledDirective.prototype.templateRef;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleWhenDisabledDirective.prototype.viewContainer;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleProviderComponent {
    constructor() {
        this.features = {};
        this.currentConfig = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `features` should not be null or empty');
        }
        this.setFeatureToggles();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        this.setFeatureToggles();
    }
    /**
     * @private
     * @return {?}
     */
    setFeatureToggles() {
        if (this.currentConfig !== this.features) {
            this.currentConfig = this.features;
            set(this.features);
        }
    }
}
FeatureToggleProviderComponent.decorators = [
    { type: Component, args: [{
                selector: 'feature-toggle-provider',
                template: `
    <ng-content></ng-content>
  `
            }] }
];
FeatureToggleProviderComponent.propDecorators = {
    features: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    FeatureToggleProviderComponent.prototype.features;
    /**
     * @type {?}
     * @private
     */
    FeatureToggleProviderComponent.prototype.currentConfig;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureToggleModule {
}
FeatureToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FeatureToggleProviderComponent, FeatureToggleDirective, FeatureToggleWhenDisabledDirective],
                exports: [FeatureToggleProviderComponent, FeatureToggleDirective, FeatureToggleWhenDisabledDirective],
                imports: [CommonModule],
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxFeatureToggleCanActivateGuard {
    /**
     * @return {?}
     */
    isDevMode() {
        return isDevMode();
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivate(route) {
        /** @type {?} */
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        if (!Array.isArray(route.data.featureToggle)) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateGuard` need to receive `featureToggle` as data as an array in your route configuration.');
            }
            return false;
        }
        /** @type {?} */
        const userCanAccess = route.data.featureToggle.every((/**
         * @param {?} toggle
         * @return {?}
         */
        toggle => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle)));
        return userCanAccess;
    }
}
NgxFeatureToggleCanActivateGuard.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ NgxFeatureToggleCanActivateGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanActivateGuard_Factory() { return new NgxFeatureToggleCanActivateGuard(); }, token: NgxFeatureToggleCanActivateGuard, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxFeatureToggleCanActivateChildGuard {
    /**
     * @return {?}
     */
    isDevMode() {
        return isDevMode();
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canActivateChild(route) {
        /** @type {?} */
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateChildGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        if (!Array.isArray(route.data.featureToggle)) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateChildGuard` need to receive `featureToggle` as data as an array in your route configuration.');
            }
            return false;
        }
        /** @type {?} */
        const userCanAccess = route.data.featureToggle.every((/**
         * @param {?} toggle
         * @return {?}
         */
        toggle => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle)));
        return userCanAccess;
    }
}
NgxFeatureToggleCanActivateChildGuard.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ NgxFeatureToggleCanActivateChildGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanActivateChildGuard_Factory() { return new NgxFeatureToggleCanActivateChildGuard(); }, token: NgxFeatureToggleCanActivateChildGuard, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxFeatureToggleCanLoadGuard {
    /**
     * @return {?}
     */
    isDevMode() {
        return isDevMode();
    }
    /**
     * @param {?} route
     * @return {?}
     */
    canLoad(route) {
        /** @type {?} */
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanLoadGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        if (!Array.isArray(route.data.featureToggle)) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanLoadGuard` need to receive `featureToggle` as data as an array in your route configuration.');
            }
            return false;
        }
        /** @type {?} */
        const userCanAccess = route.data.featureToggle.every((/**
         * @param {?} toggle
         * @return {?}
         */
        toggle => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle)));
        return userCanAccess;
    }
}
NgxFeatureToggleCanLoadGuard.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ NgxFeatureToggleCanLoadGuard.ngInjectableDef = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanLoadGuard_Factory() { return new NgxFeatureToggleCanLoadGuard(); }, token: NgxFeatureToggleCanLoadGuard, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { FeatureToggleDirective, FeatureToggleModule, FeatureToggleProviderComponent, FeatureToggleWhenDisabledDirective, NgxFeatureToggleCanActivateChildGuard, NgxFeatureToggleCanActivateGuard, NgxFeatureToggleCanLoadGuard };
//# sourceMappingURL=ngx-feature-toggle.js.map
